pub fn decode_edge_key(key: &[u8]) -> Option<DecodedEdgeKey>Expand description
Decode an edge key (tag 0x02) into its components.
Returns None if the key is malformed or not an edge key.
pub fn decode_edge_key(key: &[u8]) -> Option<DecodedEdgeKey>Decode an edge key (tag 0x02) into its components.
Returns None if the key is malformed or not an edge key.